"""_419.py

FaceGearMeshRating
"""


from typing import List

from mastapy.gears import _298
from mastapy._internal import enum_with_selected_value_runtime, constructor, conversion
from mastapy.gears.gear_designs.face import _954
from mastapy.gears.rating.face import _422, _420
from mastapy.gears.load_case.face import _847
from mastapy.gears.rating.cylindrical.iso6336 import _481, _483
from mastapy._internal.cast_exception import CastException
from mastapy.gears.rating import _332
from mastapy._internal.python_net import python_net_import

_FACE_GEAR_MESH_RATING = python_net_import('SMT.MastaAPI.Gears.Rating.Face', 'FaceGearMeshRating')


__docformat__ = 'restructuredtext en'
__all__ = ('FaceGearMeshRating',)


class FaceGearMeshRating(_332.GearMeshRating):
    """FaceGearMeshRating

    This is a mastapy class.
    """

    TYPE = _FACE_GEAR_MESH_RATING

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FaceGearMeshRating.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def active_flank(self) -> '_298.GearFlanks':
        """GearFlanks: 'ActiveFlank' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ActiveFlank
        value = conversion.pn_to_mp_enum(temp)
        return constructor.new_from_mastapy_type(_298.GearFlanks)(value) if value is not None else None

    @property
    def face_gear_mesh(self) -> '_954.FaceGearMeshDesign':
        """FaceGearMeshDesign: 'FaceGearMesh' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FaceGearMesh
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def gear_set_rating(self) -> '_422.FaceGearSetRating':
        """FaceGearSetRating: 'GearSetRating' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.GearSetRating
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def mesh_load_case(self) -> '_847.FaceMeshLoadCase':
        """FaceMeshLoadCase: 'MeshLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def mesh_single_flank_rating(self) -> '_481.ISO63362006MeshSingleFlankRating':
        """ISO63362006MeshSingleFlankRating: 'MeshSingleFlankRating' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.MeshSingleFlankRating
        if _481.ISO63362006MeshSingleFlankRating.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast mesh_single_flank_rating to ISO63362006MeshSingleFlankRating. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def face_gear_ratings(self) -> 'List[_420.FaceGearRating]':
        """List[FaceGearRating]: 'FaceGearRatings' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FaceGearRatings
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_725.py

PlungeShavingDynamicsCalculationForHobbedGears
"""


from mastapy.gears.manufacturing.cylindrical.axial_and_plunge_shaving_dynamics import _734, _721
from mastapy._internal.python_net import python_net_import

_PLUNGE_SHAVING_DYNAMICS_CALCULATION_FOR_HOBBED_GEARS = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical.AxialAndPlungeShavingDynamics', 'PlungeShavingDynamicsCalculationForHobbedGears')


__docformat__ = 'restructuredtext en'
__all__ = ('PlungeShavingDynamicsCalculationForHobbedGears',)


class PlungeShavingDynamicsCalculationForHobbedGears(_734.ShavingDynamicsCalculationForHobbedGears['_721.PlungeShaverDynamics']):
    """PlungeShavingDynamicsCalculationForHobbedGears

    This is a mastapy class.
    """

    TYPE = _PLUNGE_SHAVING_DYNAMICS_CALCULATION_FOR_HOBBED_GEARS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlungeShavingDynamicsCalculationForHobbedGears.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



"""_5874.py

BeltDriveCompoundHarmonicAnalysisOfSingleExcitation
"""


from typing import List

from mastapy.system_model.part_model.couplings import _2325, _2335
from mastapy._internal import constructor, conversion
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation import _5744
from mastapy.system_model.analyses_and_results.harmonic_analyses_single_excitation.compound import _5962
from mastapy._internal.python_net import python_net_import

_BELT_DRIVE_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalysesSingleExcitation.Compound', 'BeltDriveCompoundHarmonicAnalysisOfSingleExcitation')


__docformat__ = 'restructuredtext en'
__all__ = ('BeltDriveCompoundHarmonicAnalysisOfSingleExcitation',)


class BeltDriveCompoundHarmonicAnalysisOfSingleExcitation(_5962.SpecialisedAssemblyCompoundHarmonicAnalysisOfSingleExcitation):
    """BeltDriveCompoundHarmonicAnalysisOfSingleExcitation

    This is a mastapy class.
    """

    TYPE = _BELT_DRIVE_COMPOUND_HARMONIC_ANALYSIS_OF_SINGLE_EXCITATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'BeltDriveCompoundHarmonicAnalysisOfSingleExcitation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2325.BeltDrive':
        """BeltDrive: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        if _2325.BeltDrive.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast component_design to BeltDrive. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2325.BeltDrive':
        """BeltDrive: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        if _2325.BeltDrive.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast assembly_design to BeltDrive. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5744.BeltDriveHarmonicAnalysisOfSingleExcitation]':
        """List[BeltDriveHarmonicAnalysisOfSingleExcitation]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5744.BeltDriveHarmonicAnalysisOfSingleExcitation]':
        """List[BeltDriveHarmonicAnalysisOfSingleExcitation]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_2402.py

DesignEntitySingleContextAnalysis
"""


from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results import _2400
from mastapy._internal.python_net import python_net_import

_DESIGN_ENTITY_SINGLE_CONTEXT_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults', 'DesignEntitySingleContextAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('DesignEntitySingleContextAnalysis',)


class DesignEntitySingleContextAnalysis(_2400.DesignEntityAnalysis):
    """DesignEntitySingleContextAnalysis

    This is a mastapy class.
    """

    TYPE = _DESIGN_ENTITY_SINGLE_CONTEXT_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'DesignEntitySingleContextAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def parametric_study_index_1(self) -> 'int':
        """int: 'ParametricStudyIndex1' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ParametricStudyIndex1
        return temp

    @property
    def parametric_study_index_2(self) -> 'int':
        """int: 'ParametricStudyIndex2' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ParametricStudyIndex2
        return temp



"""_1631.py

ScatterChartDefinition
"""


from mastapy.utility_gui.charts import _1634
from mastapy._internal.python_net import python_net_import

_SCATTER_CHART_DEFINITION = python_net_import('SMT.MastaAPI.UtilityGUI.Charts', 'ScatterChartDefinition')


__docformat__ = 'restructuredtext en'
__all__ = ('ScatterChartDefinition',)


class ScatterChartDefinition(_1634.TwoDChartDefinition):
    """ScatterChartDefinition

    This is a mastapy class.
    """

    TYPE = _SCATTER_CHART_DEFINITION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ScatterChartDefinition.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



"""_2140.py

FESubstructureWithSelection
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.system_model.fe import (
    _2133, _2126, _2151, _2111
)
from mastapy._internal.python_net import python_net_import

_FE_SUBSTRUCTURE_WITH_SELECTION = python_net_import('SMT.MastaAPI.SystemModel.FE', 'FESubstructureWithSelection')


__docformat__ = 'restructuredtext en'
__all__ = ('FESubstructureWithSelection',)


class FESubstructureWithSelection(_2111.BaseFEWithSelection):
    """FESubstructureWithSelection

    This is a mastapy class.
    """

    TYPE = _FE_SUBSTRUCTURE_WITH_SELECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'FESubstructureWithSelection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def selected_nodes(self) -> 'str':
        """str: 'SelectedNodes' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SelectedNodes
        return temp

    @property
    def fe_substructure(self) -> '_2133.FESubstructure':
        """FESubstructure: 'FESubstructure' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.FESubstructure
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def element_face_groups(self) -> 'List[_2126.ElementFaceGroupWithSelection]':
        """List[ElementFaceGroupWithSelection]: 'ElementFaceGroups' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ElementFaceGroups
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def node_groups(self) -> 'List[_2151.NodeGroupWithSelection]':
        """List[NodeGroupWithSelection]: 'NodeGroups' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.NodeGroups
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    def create_condensation_node_connected_to_current_selection(self):
        """ 'CreateCondensationNodeConnectedToCurrentSelection' is the original name of this method."""

        self.wrapped.CreateCondensationNodeConnectedToCurrentSelection()

    def create_element_face_group(self):
        """ 'CreateElementFaceGroup' is the original name of this method."""

        self.wrapped.CreateElementFaceGroup()

    def create_node_group(self):
        """ 'CreateNodeGroup' is the original name of this method."""

        self.wrapped.CreateNodeGroup()

    def ground_selected_faces(self):
        """ 'GroundSelectedFaces' is the original name of this method."""

        self.wrapped.GroundSelectedFaces()

    def remove_grounding_on_selected_faces(self):
        """ 'RemoveGroundingOnSelectedFaces' is the original name of this method."""

        self.wrapped.RemoveGroundingOnSelectedFaces()



"""_5284.py

ClutchCompoundMultibodyDynamicsAnalysis
"""


from typing import List

from mastapy.system_model.part_model.couplings import _2327
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.mbd_analyses import _5136
from mastapy.system_model.analyses_and_results.mbd_analyses.compound import _5300
from mastapy._internal.python_net import python_net_import

_CLUTCH_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses.Compound', 'ClutchCompoundMultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ClutchCompoundMultibodyDynamicsAnalysis',)


class ClutchCompoundMultibodyDynamicsAnalysis(_5300.CouplingCompoundMultibodyDynamicsAnalysis):
    """ClutchCompoundMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE = _CLUTCH_COMPOUND_MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ClutchCompoundMultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2327.Clutch':
        """Clutch: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_design(self) -> '_2327.Clutch':
        """Clutch: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5136.ClutchMultibodyDynamicsAnalysis]':
        """List[ClutchMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCasesReady
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5136.ClutchMultibodyDynamicsAnalysis]':
        """List[ClutchMultibodyDynamicsAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.AssemblyAnalysisCases
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_2235.py

SpecifiedParallelPartGroupDrawingOrder
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy.system_model.part_model.projections import _2234
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_SPECIFIED_PARALLEL_PART_GROUP_DRAWING_ORDER = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Projections', 'SpecifiedParallelPartGroupDrawingOrder')


__docformat__ = 'restructuredtext en'
__all__ = ('SpecifiedParallelPartGroupDrawingOrder',)


class SpecifiedParallelPartGroupDrawingOrder(_0.APIBase):
    """SpecifiedParallelPartGroupDrawingOrder

    This is a mastapy class.
    """

    TYPE = _SPECIFIED_PARALLEL_PART_GROUP_DRAWING_ORDER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpecifiedParallelPartGroupDrawingOrder.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self) -> 'str':
        """str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Name
        return temp

    @property
    def specified_groups(self) -> 'List[_2234.SpecifiedConcentricPartGroupDrawingOrder]':
        """List[SpecifiedConcentricPartGroupDrawingOrder]: 'SpecifiedGroups' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.SpecifiedGroups
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._1729 import BallBearingContactCalculation
    from ._1730 import BallBearingRaceContactGeometry
    from ._1731 import DIN732Results
    from ._1732 import ForceAtLaminaGroupReportable
    from ._1733 import ForceAtLaminaReportable
    from ._1734 import FrictionModelForGyroscopicMoment
    from ._1735 import InternalClearance
    from ._1736 import ISO14179Settings
    from ._1737 import ISO14179SettingsDatabase
    from ._1738 import ISO14179SettingsPerBearingType
    from ._1739 import LoadedAbstractSphericalRollerBearingStripLoadResults
    from ._1740 import LoadedAngularContactBallBearingElement
    from ._1741 import LoadedAngularContactBallBearingResults
    from ._1742 import LoadedAngularContactBallBearingRow
    from ._1743 import LoadedAngularContactThrustBallBearingElement
    from ._1744 import LoadedAngularContactThrustBallBearingResults
    from ._1745 import LoadedAngularContactThrustBallBearingRow
    from ._1746 import LoadedAsymmetricSphericalRollerBearingElement
    from ._1747 import LoadedAsymmetricSphericalRollerBearingResults
    from ._1748 import LoadedAsymmetricSphericalRollerBearingRow
    from ._1749 import LoadedAsymmetricSphericalRollerBearingStripLoadResults
    from ._1750 import LoadedAxialThrustCylindricalRollerBearingDutyCycle
    from ._1751 import LoadedAxialThrustCylindricalRollerBearingElement
    from ._1752 import LoadedAxialThrustCylindricalRollerBearingResults
    from ._1753 import LoadedAxialThrustCylindricalRollerBearingRow
    from ._1754 import LoadedAxialThrustNeedleRollerBearingElement
    from ._1755 import LoadedAxialThrustNeedleRollerBearingResults
    from ._1756 import LoadedAxialThrustNeedleRollerBearingRow
    from ._1757 import LoadedBallBearingDutyCycle
    from ._1758 import LoadedBallBearingElement
    from ._1759 import LoadedBallBearingRaceResults
    from ._1760 import LoadedBallBearingResults
    from ._1761 import LoadedBallBearingRow
    from ._1762 import LoadedCrossedRollerBearingElement
    from ._1763 import LoadedCrossedRollerBearingResults
    from ._1764 import LoadedCrossedRollerBearingRow
    from ._1765 import LoadedCylindricalRollerBearingDutyCycle
    from ._1766 import LoadedCylindricalRollerBearingElement
    from ._1767 import LoadedCylindricalRollerBearingResults
    from ._1768 import LoadedCylindricalRollerBearingRow
    from ._1769 import LoadedDeepGrooveBallBearingElement
    from ._1770 import LoadedDeepGrooveBallBearingResults
    from ._1771 import LoadedDeepGrooveBallBearingRow
    from ._1772 import LoadedElement
    from ._1773 import LoadedFourPointContactBallBearingElement
    from ._1774 import LoadedFourPointContactBallBearingRaceResults
    from ._1775 import LoadedFourPointContactBallBearingResults
    from ._1776 import LoadedFourPointContactBallBearingRow
    from ._1777 import LoadedMultiPointContactBallBearingElement
    from ._1778 import LoadedNeedleRollerBearingElement
    from ._1779 import LoadedNeedleRollerBearingResults
    from ._1780 import LoadedNeedleRollerBearingRow
    from ._1781 import LoadedNonBarrelRollerBearingDutyCycle
    from ._1782 import LoadedNonBarrelRollerBearingResults
    from ._1783 import LoadedNonBarrelRollerBearingRow
    from ._1784 import LoadedNonBarrelRollerBearingStripLoadResults
    from ._1785 import LoadedNonBarrelRollerElement
    from ._1786 import LoadedRollerBearingElement
    from ._1787 import LoadedRollerBearingResults
    from ._1788 import LoadedRollerBearingRow
    from ._1789 import LoadedRollerStripLoadResults
    from ._1790 import LoadedRollingBearingRaceResults
    from ._1791 import LoadedRollingBearingResults
    from ._1792 import LoadedRollingBearingRow
    from ._1793 import LoadedSelfAligningBallBearingElement
    from ._1794 import LoadedSelfAligningBallBearingResults
    from ._1795 import LoadedSelfAligningBallBearingRow
    from ._1796 import LoadedSphericalRadialRollerBearingElement
    from ._1797 import LoadedSphericalRollerBearingElement
    from ._1798 import LoadedSphericalRollerRadialBearingResults
    from ._1799 import LoadedSphericalRollerRadialBearingRow
    from ._1800 import LoadedSphericalRollerRadialBearingStripLoadResults
    from ._1801 import LoadedSphericalRollerThrustBearingResults
    from ._1802 import LoadedSphericalRollerThrustBearingRow
    from ._1803 import LoadedSphericalRollerThrustBearingStripLoadResults
    from ._1804 import LoadedSphericalThrustRollerBearingElement
    from ._1805 import LoadedTaperRollerBearingDutyCycle
    from ._1806 import LoadedTaperRollerBearingElement
    from ._1807 import LoadedTaperRollerBearingResults
    from ._1808 import LoadedTaperRollerBearingRow
    from ._1809 import LoadedThreePointContactBallBearingElement
    from ._1810 import LoadedThreePointContactBallBearingResults
    from ._1811 import LoadedThreePointContactBallBearingRow
    from ._1812 import LoadedThrustBallBearingElement
    from ._1813 import LoadedThrustBallBearingResults
    from ._1814 import LoadedThrustBallBearingRow
    from ._1815 import LoadedToroidalRollerBearingElement
    from ._1816 import LoadedToroidalRollerBearingResults
    from ._1817 import LoadedToroidalRollerBearingRow
    from ._1818 import LoadedToroidalRollerBearingStripLoadResults
    from ._1819 import MaximumStaticContactStress
    from ._1820 import MaximumStaticContactStressDutyCycle
    from ._1821 import MaximumStaticContactStressResultsAbstract
    from ._1822 import MaxStripLoadStressObject
    from ._1823 import PermissibleContinuousAxialLoadResults
    from ._1824 import PowerRatingF1EstimationMethod
    from ._1825 import PreloadFactorLookupTable
    from ._1826 import ResultsAtRollerOffset
    from ._1827 import RingForceAndDisplacement
    from ._1828 import RollerAnalysisMethod
    from ._1829 import RollingBearingFrictionCoefficients
    from ._1830 import RollingBearingSpeedResults
    from ._1831 import SMTRibStressResults
    from ._1832 import StressAtPosition
    from ._1833 import ThreePointContactInternalClearance
    from ._1834 import TrackTruncationSafetyFactorResults



"""_1084.py

ReliefWithDeviation
"""


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_RELIEF_WITH_DEVIATION = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry', 'ReliefWithDeviation')


__docformat__ = 'restructuredtext en'
__all__ = ('ReliefWithDeviation',)


class ReliefWithDeviation(_0.APIBase):
    """ReliefWithDeviation

    This is a mastapy class.
    """

    TYPE = _RELIEF_WITH_DEVIATION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ReliefWithDeviation.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def lower_limit(self) -> 'float':
        """float: 'LowerLimit' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LowerLimit
        return temp

    @property
    def relief(self) -> 'float':
        """float: 'Relief' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Relief
        return temp

    @property
    def section(self) -> 'str':
        """str: 'Section' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Section
        return temp

    @property
    def upper_limit(self) -> 'float':
        """float: 'UpperLimit' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.UpperLimit
        return temp



"""_6602.py

ElectricMachineHarmonicLoadExcelImportOptions
"""


from mastapy.system_model.analyses_and_results.static_loads import _6604
from mastapy._internal.python_net import python_net_import

_ELECTRIC_MACHINE_HARMONIC_LOAD_EXCEL_IMPORT_OPTIONS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'ElectricMachineHarmonicLoadExcelImportOptions')


__docformat__ = 'restructuredtext en'
__all__ = ('ElectricMachineHarmonicLoadExcelImportOptions',)


class ElectricMachineHarmonicLoadExcelImportOptions(_6604.ElectricMachineHarmonicLoadImportOptionsBase):
    """ElectricMachineHarmonicLoadExcelImportOptions

    This is a mastapy class.
    """

    TYPE = _ELECTRIC_MACHINE_HARMONIC_LOAD_EXCEL_IMPORT_OPTIONS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElectricMachineHarmonicLoadExcelImportOptions.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



"""_2318.py

CycloidalDisc
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy._internal.python_net import python_net_import
from mastapy.cycloidal import _1262, _1263, _1269
from mastapy.materials import _245, _223
from mastapy.shafts import _24
from mastapy._internal.cast_exception import CastException
from mastapy.gears.materials import (
    _549, _551, _553, _557,
    _560, _563, _567, _569
)
from mastapy.detailed_rigid_connectors.splines import _1224
from mastapy.bolts import _1272, _1276
from mastapy.system_model.part_model import _2211, _2187
from mastapy.system_model.connections_and_sockets.cycloidal import _2090

_DATABASE_WITH_SELECTED_ITEM = python_net_import('SMT.MastaAPI.UtilityGUI.Databases', 'DatabaseWithSelectedItem')
_CYCLOIDAL_DISC = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Cycloidal', 'CycloidalDisc')


__docformat__ = 'restructuredtext en'
__all__ = ('CycloidalDisc',)


class CycloidalDisc(_2187.AbstractShaft):
    """CycloidalDisc

    This is a mastapy class.
    """

    TYPE = _CYCLOIDAL_DISC

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CycloidalDisc.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def bore_diameter(self) -> 'float':
        """float: 'BoreDiameter' is the original name of this property."""

        temp = self.wrapped.BoreDiameter
        return temp

    @bore_diameter.setter
    def bore_diameter(self, value: 'float'):
        self.wrapped.BoreDiameter = float(value) if value else 0.0

    @property
    def disc_material_database(self) -> 'str':
        """str: 'DiscMaterialDatabase' is the original name of this property."""

        temp = self.wrapped.DiscMaterialDatabase.SelectedItemName
        return temp

    @disc_material_database.setter
    def disc_material_database(self, value: 'str'):
        self.wrapped.DiscMaterialDatabase.SetSelectedItem(str(value) if value else '')

    @property
    def hole_diameter_for_eccentric_bearing(self) -> 'float':
        """float: 'HoleDiameterForEccentricBearing' is the original name of this property."""

        temp = self.wrapped.HoleDiameterForEccentricBearing
        return temp

    @hole_diameter_for_eccentric_bearing.setter
    def hole_diameter_for_eccentric_bearing(self, value: 'float'):
        self.wrapped.HoleDiameterForEccentricBearing = float(value) if value else 0.0

    @property
    def length(self) -> 'float':
        """float: 'Length' is the original name of this property."""

        temp = self.wrapped.Length
        return temp

    @length.setter
    def length(self, value: 'float'):
        self.wrapped.Length = float(value) if value else 0.0

    @property
    def number_of_planetary_sockets(self) -> 'int':
        """int: 'NumberOfPlanetarySockets' is the original name of this property."""

        temp = self.wrapped.NumberOfPlanetarySockets
        return temp

    @number_of_planetary_sockets.setter
    def number_of_planetary_sockets(self, value: 'int'):
        self.wrapped.NumberOfPlanetarySockets = int(value) if value else 0

    @property
    def cycloidal_disc_design(self) -> '_1262.CycloidalDiscDesign':
        """CycloidalDiscDesign: 'CycloidalDiscDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.CycloidalDiscDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def disc_material(self) -> '_245.Material':
        """Material: 'DiscMaterial' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.DiscMaterial
        if _245.Material.TYPE not in temp.__class__.__mro__:
            raise CastException('Failed to cast disc_material to Material. Expected: {}.'.format(temp.__class__.__qualname__))

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def load_sharing_settings(self) -> '_2211.LoadSharingSettings':
        """LoadSharingSettings: 'LoadSharingSettings' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.LoadSharingSettings
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def planetary_bearing_sockets(self) -> 'List[_2090.CycloidalDiscPlanetaryBearingSocket]':
        """List[CycloidalDiscPlanetaryBearingSocket]: 'PlanetaryBearingSockets' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PlanetaryBearingSockets
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""_2534.py

PlanetCarrierSystemDeflection
"""


from typing import List

from mastapy.system_model.part_model import _2219
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.static_loads import _6662
from mastapy.system_model.analyses_and_results.power_flows import _3860
from mastapy.system_model.analyses_and_results.system_deflections.reporting import _2590
from mastapy.system_model.analyses_and_results.system_deflections import _2526
from mastapy._internal.python_net import python_net_import

_PLANET_CARRIER_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'PlanetCarrierSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('PlanetCarrierSystemDeflection',)


class PlanetCarrierSystemDeflection(_2526.MountableComponentSystemDeflection):
    """PlanetCarrierSystemDeflection

    This is a mastapy class.
    """

    TYPE = _PLANET_CARRIER_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'PlanetCarrierSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2219.PlanetCarrier':
        """PlanetCarrier: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentDesign
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def component_load_case(self) -> '_6662.PlanetCarrierLoadCase':
        """PlanetCarrierLoadCase: 'ComponentLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ComponentLoadCase
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def power_flow_results(self) -> '_3860.PlanetCarrierPowerFlow':
        """PlanetCarrierPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.PowerFlowResults
        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp) if temp is not None else None

    @property
    def windup(self) -> 'List[_2590.PlanetCarrierWindup]':
        """List[PlanetCarrierWindup]: 'Windup' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.Windup
        value = conversion.pn_to_mp_objects_in_list(temp)
        return value



"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._531 import AGMAGleasonConicalGearMeshRating
    from ._532 import AGMAGleasonConicalGearRating
    from ._533 import AGMAGleasonConicalGearSetRating
    from ._534 import AGMAGleasonConicalRateableMesh
